======
ragnar
======


.. image:: https://img.shields.io/pypi/v/ragnar.svg
        :target: https://pypi.python.org/pypi/ragnar

.. image:: https://img.shields.io/travis/vikilab/ragnar.svg
        :target: https://travis-ci.org/vikilab/ragnar

.. image:: https://readthedocs.org/projects/ragnar/badge/?version=latest
        :target: https://ragnar.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://coveralls.io/repos/github/vikilab/ragnar/badge.svg?branch=master
	:target: https://coveralls.io/github/vikilab/ragnar?branch=master



Ragnar is a lightweight Extract-Transform-Load (ETL) framework for Python 3.5+.


* Free software: MIT license
* Documentation: https://ragnar.readthedocs.io.


Features
--------

* TODO

Credits
-------


